summaryrefslogtreecommitdiffstats
path: root/kcron/ktlistitem.h
diff options
context:
space:
mode:
Diffstat (limited to 'kcron/ktlistitem.h')
-rw-r--r--kcron/ktlistitem.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kcron/ktlistitem.h b/kcron/ktlistitem.h
index 6d10974..718fb79 100644
--- a/kcron/ktlistitem.h
+++ b/kcron/ktlistitem.h
@@ -16,13 +16,13 @@
#include <config.h>
#endif
-#include <qlistview.h>
+#include <tqlistview.h>
class KTPrint;
class CTCron;
/**
* An enhanced QListViewItem that ensures all list view items have the
* same interface.
*/
class KTListItem : public QListViewItem
@@ -37,7 +37,7 @@ public:
/**
* Construct a non-root list view item from a CTCron.
*/
- KTListItem(QListView* parent, const char* name, CTCron* _ctcron);
+ KTListItem(TQListView* parent, const char* name, CTCron* _ctcron);
/**
* Destructor.
@@ -16,13 +16,13 @@
class CTCron;
/**
- * An enhanced QListViewItem that ensures all list view items have the
+ * An enhanced TQListViewItem that ensures all list view items have the
* same interface.
*/